<?php
/**
 * Sample implementation of the Custom Header feature
 *
 * You can add an optional custom header image to header.php like so ...
 *
	<?php the_header_image_tag(); ?>
 *
 * @link https://developer.wordpress.org/themes/functionality/custom-headers/
 *
 * @package Big_Bob
 */

/**
 * Set up the WordPress core custom header feature.
 *
 * @uses big_bob_header_style()
 */
function big_bob_custom_header_setup() {
	add_theme_support(
		'custom-header',
		apply_filters(
			'big_bob_custom_header_args',
			array(
				'default-text-color' => '000000',
				'width'              => 2000,
				'height'             => 1200,
				'flex-height'        => true,
				'flex-width'         => true,
				'wp-head-callback'   => 'big_bob_header_style',
				'video' => true,
			)
		)
	);

}


// Enable video header support on mobile devices
add_filter( 'header_video_settings', function( $args ) {

	$args['minWidth'] = 0;
	$args['minHeight'] = 0;

	return $args;

} );

add_action( 'after_setup_theme', 'big_bob_custom_header_setup' );

if ( ! function_exists( 'big_bob_header_style' ) ) :
	/**
	 * Styles the header image and text displayed on the blog.
	 *
	 * @see big_bob_custom_header_setup().
	 */
	function big_bob_header_style() {
		$header_text_color = get_header_textcolor();

		/*
		 * If no custom options for text are set, let's bail.
		 * get_header_textcolor() options: Any hex value, 'blank' to hide text. Default: add_theme_support( 'custom-header' ).
		 */
		if ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color ) {
			return;
		}

		// If we get this far, we have custom styles. Let's do this.
		?>
		<style type="text/css">
		
			<?php
		//remove wp-custom header references for customizer; set to deault
		//since .wp-cusotm-header isn't empty in customizer, the margin for top-padding needs replacement
		//Has the text been hidden?
		//$custom_header = get_custom_header_markup();
		if (!get_header_image() && !has_header_video() && !display_header_text() && !is_front_page() ) :
			?>
			.wp-custom-header,
			.wp-custom-header img,
			.wp-custom-header video {
				width: auto;
				height: auto;
				min-width: 0; 
				min-height: 0;
				max-width: none; 
				max-height: none; 
			}
			.wp-custom-header {
				margin: 160px;
			}
			.site-title,
			.site-description {
				position: absolute;
				clip: rect(1px, 1px, 1px, 1px);
				}
			.site-branding {
				margin-bottom: 20px;
			}
			.top-padding {
				margin: 160px;
			}
			<?php
		elseif (( get_theme_mod( 'video_on_phone', 'On' ) == 'Off' ) && !get_header_image() && has_header_video() && !display_header_text()) :
			?>
			@media screen and (max-width: 500px) {
				.wp-custom-header,
				.wp-custom-header img,
				.wp-custom-header video {
					width: auto;
					height: auto;
					min-width: 0; 
					min-height: 0;
					max-width: none; 
					max-height: none; 
				}
				.wp-custom-header {
					margin: 160px;
				}
				.site-title,
				.site-description {
					position: absolute;
					clip: rect(1px, 1px, 1px, 1px);
					}
				.site-branding {
					margin-bottom: 20px;
				}
				.top-padding {
					margin: 160px;
				}
			}
		<?php
		endif;
		// Has the text been hidden?
		if ( ! display_header_text() ) :
			?>
			.site-title,
			.site-description {
				position: absolute;
				clip: rect(1px, 1px, 1px, 1px);
				}
			.site-branding {
				margin-bottom: 20px;
			}
			.top-padding {
				margin: 160px;
			}
			<?php
			// If the user has set a custom color for the text use that.
		else :
			?>
			.site-title a,
			.site-description {
				color: #<?php echo esc_attr( $header_text_color ); ?>;
			}
		<?php endif;?>
		</style>
		<?php
	}
endif;
add_action( 'wp_head', 'big_bob_header_style' );